#include "gui.h"
#include "unpacker.h"
//#include "unpacker.cxx"

MainFrame::MainFrame(const TGWindow *p, UInt_t width, UInt_t height):TGMainFrame(p, width, height, kMainFrame|kHorizontalFrame)
{

   //---- Left Frame - for buttons and user values
   fr_left  = new TGVerticalFrame(this, 0.3*width, height, kChildFrame|kFixedSize); 
   
   // The 1st grouped frame - runs
   fr_runs = new TGGroupFrame(fr_left, "Run", kChildFrame | kVerticalFrame|kFixedSize);   
   box_run = new TGNumberEntry(fr_runs, (Double_t) 0, 10, -1, (TGNumberFormat::EStyle) 5);  
   fr_runs->AddFrame(box_run, new TGLayoutHints(kLHintsLeft | kLHintsCenterY, 2, 2, 2, 2) );
   fr_left->AddFrame(fr_runs, new TGLayoutHints(kLHintsExpandX, 2, 2, 2, 2));
   
   // The 2nd grouped frame - Drawing the signal
   fr_draw = new TGGroupFrame(fr_left, "Draw", kChildFrame | kHorizontalFrame|kFixedSize);   
   TGTextButton *but_draw_histo = new TGTextButton(fr_draw, "&Draw");
   but_draw_histo->Connect("Clicked()", "MainFrame", this, "test_unpack()");   
   fr_draw->AddFrame(but_draw_histo, new TGLayoutHints(kLHintsLeft | kLHintsCenterY, 2, 2, 2, 2) );
   fr_left->AddFrame(fr_draw, new TGLayoutHints(kLHintsExpandX, 2, 2, 2, 2));
  
   // Test button to see the structure
   TGTextButton *test = new TGTextButton(fr_left,"&Test");
   test->Connect("Clicked()", "MainFrame", this, "draw_test()");
   fr_left->AddFrame(test, new TGLayoutHints(kLHintsCenterX | kLHintsCenterY, 10, 10, 10, 10) );
   
   // Exit button to exit the application
   TGTextButton *exit = new TGTextButton(fr_left, "&Exit", "gApplication->Terminate(0)");
   fr_left->AddFrame(exit, new TGLayoutHints(kLHintsCenterX, 5, 5, 3, 4) );                                        
   AddFrame(fr_left , new TGLayoutHints(kLHintsLeft | kLHintsTop, 10,10,10,10));
  
   
   //---- Right frame - for the canvas
   TGVerticalFrame *fr_right = new TGVerticalFrame(this, 0.7*width, height, kChildFrame);   
   emb_canvas = new TRootEmbeddedCanvas("canvas", fr_right, 130, 180);
   fr_right->AddFrame(emb_canvas, new TGLayoutHints(kLHintsExpandX | kLHintsExpandY, 10,10,10,10));   
   AddFrame(fr_right , new TGLayoutHints(kLHintsExpandX | kLHintsExpandY, 10,10,10,10));

    // Set a name to the main frame
   SetWindowName("Signal viewer");
   
   // Map all subwindows of main frame
   MapSubwindows();
   Layout();
   
   // Initialize the layout algorithm
   Resize(GetDefaultSize());
   
   // Map main frame
   MapWindow();

}

////////////////////////////////////////////////////////////////////////////////
/// Handles resize events for the mainframe.

Bool_t MainFrame::HandleConfigureNotify(Event_t *event)
{
    // set the size minus the margins set in the LayoutManager:
   // AddFrame(fr_left , new TGLayoutHints(kLHintsLeft | kLHintsTop, 10,10,10,10));
   UInt_t w = event->fWidth-20;
   UInt_t h = event->fHeight-20;
   
   fr_runs->Resize(0.25*w, 0.15*h);
   fr_runs->Layout();
   
   fr_draw->Resize(0.25*w, 0.15*h);
   fr_draw->Layout();
   
   fr_left->Resize(0.25*w, h);
   fr_left->Layout();
   
   return TGMainFrame::HandleConfigureNotify(event);
}

void MainFrame::draw_test() {
   // Draws function graphics in randomly chosen interval
   TF1 *f1 = new TF1("f1","sin(x)/x",0,gRandom->Rndm()*10);
   f1->SetLineWidth(3);
   f1->Draw();
   TCanvas *fCanvas = emb_canvas->GetCanvas();
   fCanvas->cd();
   fCanvas->Update();
}

MainFrame::~MainFrame() {
   // Clean up used widgets: frames, buttons, layout hints
   Cleanup();
}

void start_gui(){
   // Popup the gui
   std::cout << "Starting the gui" << std::endl;
   new MainFrame(gClient->GetRoot(), 800, 500);
}

//int test_unpack();

